==> zio-aws-imagebuilder_2.13-5.17.130.6-sources.jar: zio/aws/imagebuilder/model/ListComponentsRequest.scala <==
package zio.aws.imagebuilder.model
import java.lang.Integer
import zio.aws.imagebuilder.model.primitives.{
  PaginationToken,
  RestrictedInteger
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListComponentsRequest(
    owner: Option[zio.aws.imagebuilder.model.Ownership] = None,
    filters: Option[Iterable[zio.aws.imagebuilder.model.Filter]] = None,
    byName: Option[Boolean] = None,
    maxResults: Option[RestrictedInteger] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest = {
    import ListComponentsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
      .builder()
      .optionallyWith(owner.map(value => value.unwrap))(_.owner)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(byName.map(value => value: java.lang.Boolean))(_.byName)
      .optionallyWith(
        maxResults.map(value => RestrictedInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.imagebuilder.model.ListComponentsRequest.ReadOnly =
    zio.aws.imagebuilder.model.ListComponentsRequest.wrap(buildAwsValue())
}
object ListComponentsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.ListComponentsRequest =
      zio.aws.imagebuilder.model.ListComponentsRequest(
        owner.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        byName.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def owner: Option[zio.aws.imagebuilder.model.Ownership]
    def filters: Option[List[zio.aws.imagebuilder.model.Filter.ReadOnly]]
    def byName: Option[Boolean]
    def maxResults: Option[RestrictedInteger]
    def nextToken: Option[PaginationToken]
    def getOwner: ZIO[Any, AwsError, zio.aws.imagebuilder.model.Ownership] =
      AwsError.unwrapOptionField("owner", owner)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getByName: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("byName", byName)
    def getMaxResults: ZIO[Any, AwsError, RestrictedInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
  ) extends zio.aws.imagebuilder.model.ListComponentsRequest.ReadOnly {
    override val owner: Option[zio.aws.imagebuilder.model.Ownership] = scala
      .Option(impl.owner())
      .map(value => zio.aws.imagebuilder.model.Ownership.wrap(value))
    override val filters
        : Option[List[zio.aws.imagebuilder.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.imagebuilder.model.Filter.wrap(item)
        }.toList
      )
    override val byName: Option[Boolean] =
      scala.Option(impl.byName()).map(value => value: Boolean)
    override val maxResults: Option[RestrictedInteger] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.RestrictedInteger(value)
      )
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
  ): zio.aws.imagebuilder.model.ListComponentsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-imagebuilder_2.13-5.17.205.1-sources.jar: zio/aws/imagebuilder/model/ListComponentsRequest.scala <==
package zio.aws.imagebuilder.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.imagebuilder.model.primitives.{
  PaginationToken,
  RestrictedInteger
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListComponentsRequest(
    owner: Optional[zio.aws.imagebuilder.model.Ownership] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.imagebuilder.model.Filter]] =
      Optional.Absent,
    byName: Optional[Boolean] = Optional.Absent,
    maxResults: Optional[RestrictedInteger] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest = {
    import ListComponentsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
      .builder()
      .optionallyWith(owner.map(value => value.unwrap))(_.owner)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(byName.map(value => value: java.lang.Boolean))(_.byName)
      .optionallyWith(
        maxResults.map(value => RestrictedInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.imagebuilder.model.ListComponentsRequest.ReadOnly =
    zio.aws.imagebuilder.model.ListComponentsRequest.wrap(buildAwsValue())
}
object ListComponentsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.ListComponentsRequest =
      zio.aws.imagebuilder.model.ListComponentsRequest(
        owner.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        byName.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def owner: Optional[zio.aws.imagebuilder.model.Ownership]
    def filters: Optional[List[zio.aws.imagebuilder.model.Filter.ReadOnly]]
    def byName: Optional[Boolean]
    def maxResults: Optional[RestrictedInteger]
    def nextToken: Optional[PaginationToken]
    def getOwner: ZIO[Any, AwsError, zio.aws.imagebuilder.model.Ownership] =
      AwsError.unwrapOptionField("owner", owner)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getByName: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("byName", byName)
    def getMaxResults: ZIO[Any, AwsError, RestrictedInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
  ) extends zio.aws.imagebuilder.model.ListComponentsRequest.ReadOnly {
    override val owner: Optional[zio.aws.imagebuilder.model.Ownership] =
      zio.aws.core.internal
        .optionalFromNullable(impl.owner())
        .map(value => zio.aws.imagebuilder.model.Ownership.wrap(value))
    override val filters
        : Optional[List[zio.aws.imagebuilder.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.imagebuilder.model.Filter.wrap(item)
          }.toList
        )
    override val byName: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.byName())
      .map(value => value: Boolean)
    override val maxResults: Optional[RestrictedInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.RestrictedInteger(value)
      )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.ListComponentsRequest
  ): zio.aws.imagebuilder.model.ListComponentsRequest.ReadOnly = new Wrapper(
    impl
  )
}
